==> react-native-onboard-2.4.23.tgz: package/lib/OnboardFlow/pages/FormEntryPage/index.js <==
import React from 'react';
import { KeyboardAvoidingView, StyleSheet, View } from 'react-native';
import { HORIZONTAL_PADDING_DEFAULT, VERTICAL_PADDING_DEFAULT } from '../../constants';
import { InputField } from '../../components/InputField';
import { TextStack } from '../../components/TextStack';
export const FormEntryPage = ({ style, titleStyle, subtitleStyle, textStyle, pageData, currentPage, totalPages, goToNextPage, goToPreviousPage, onSaveData, textAlign, width, props, }) => {
    return (<View style={[
            styles.container,
            style,
            {
                width: width,
                paddingHorizontal: HORIZONTAL_PADDING_DEFAULT,
                paddingTop: VERTICAL_PADDING_DEFAULT,
            },
        ]}>
      <KeyboardAvoidingView>
        <TextStack title={pageData?.title} subtitle={pageData?.subtitle} textStyle={textStyle} textAlign={textAlign} titleStyle={titleStyle} subtitleStyle={subtitleStyle}></TextStack>
        {props.fields.map((input, index) => (<View style={[{ marginTop: VERTICAL_PADDING_DEFAULT }]} key={index}>
            <InputField onSetText={(text) => {
                if (onSaveData) {
                    onSaveData({
                        source: pageData,
                        data: {
                            id: input.id,
                            value: text,
                        },
                    });
                }
                if (input.onSetText) {
                    input.onSetText(text);
                }
            }} {...input}/>
          </View>))}
      </KeyboardAvoidingView>
    </View>);
};
const styles = StyleSheet.create({
    container: {
        flex: 1,
        flexDirection: 'column',
    },
});

==> react-native-onboard-2.4.26.tgz: package/lib/OnboardFlow/pages/FormEntryPage/index.js <==
import React from 'react';
import { KeyboardAvoidingView, StyleSheet, View } from 'react-native';
import { HORIZONTAL_PADDING_DEFAULT, VERTICAL_PADDING_DEFAULT } from '../../constants';
import { InputField } from '../../components/InputField';
import { TextStack } from '../../components/TextStack';
export const FormEntryPage = ({ style, titleStyle, subtitleStyle, textStyle, pageData, currentPage, totalPages, goToNextPage, goToPreviousPage, onSaveData, textAlign, width, primaryColor, secondaryColor, props, }) => {
    return (<View style={[
            styles.container,
            style,
            {
                width: width,
                paddingHorizontal: HORIZONTAL_PADDING_DEFAULT,
                paddingTop: VERTICAL_PADDING_DEFAULT,
            },
        ]}>
      <KeyboardAvoidingView>
        <TextStack title={pageData?.title} subtitle={pageData?.subtitle} textStyle={textStyle} textAlign={textAlign} titleStyle={titleStyle} subtitleStyle={subtitleStyle}></TextStack>
        {props.fields.map((input, index) => (<View style={[{ marginTop: VERTICAL_PADDING_DEFAULT }]} key={index}>
            <InputField onSetText={(text) => {
                if (onSaveData) {
                    onSaveData({
                        source: pageData,
                        data: {
                            id: input.id,
                            value: text,
                        },
                    });
                }
                if (input.onSetText) {
                    input.onSetText(text);
                }
            }} primaryColor={primaryColor} secondaryColor={secondaryColor} {...input}/>
          </View>))}
      </KeyboardAvoidingView>
    </View>);
};
const styles = StyleSheet.create({
    container: {
        flex: 1,
        flexDirection: 'column',
    },
});
